import request from "@/utils/requestOms";
import i18n from "@/lang"; // 国际化

// 手动寻源
export function manualOrderSource(query) {
  return request({
    url: "/orders/manualOrderSource",
    method: "get",
    params: query
  });
}
// 手动拆单
export function manualSpiltOrder(data) {
  return request({
    url: "/orders/manualSpiltOrder",
    method: "post",
    data
  });
}
// 检测是否会拆出纯赠品订单
export function checkActivityProduct(data) {
  return request({
    url: "/orders/checkActivityProduct",
    method: "post",
    data
  });
}

// 发货
export function orderShip(data) {
  return request({
    url: "/orders/orderShip",
    method: "post",
    data
  });
}

// 唯一码匹配
export function shipUniqueCodeMatch(query) {
  return request({
    url: "/orders/shipUniqueCodeMatch",
    method: "get",
    params: query
  });
}

// 可发货列表
export function getShippableOrders(query) {
  return request({
    url: "/orders/getShippableOrders",
    method: "get",
    params: query
  });
}

// 审核订单
export function queryOrderDetails(id) {
  return request({
    url: "/orders/queryOrderDetails/" + id,
    method: "get"
  });
}
//查询订单支付方式
export function queryOrderGiftCard(id) {
  return request({
    url: "/orders/queryOrderGiftCard/" + id,
    method: "get"
  });
}

//通过网店单号查询
export function queryOrderDetailsByOrmorder(query) {
  return request({
    url: "/orders/queryOrderDetailsByOrmorder",
    method: "get",
    params: query
  });
}

//修改内部备注
export function addNote(query) {
  return request({
    url: "/orders/handleAddNote",
    method: "get",
    params: query
  });
}

//修改地址备注
export function editAddress(query) {
  return request({
    url: "/orders/handleEditAddress",
    method: "get",
    params: query
  });
}

//通过发货单号查询订单项数据
export function queryOrderItemList(id) {
  return request({
    url: "/orders/queryOrderItemList/" + id,
    method: "get"
  });
}

//订单挂起
export function suspend(query) {
  return request({
    url: "/orders/handleSuspend",
    method: "get",
    params: query
  });
}

// 作废订单
export function invalid(id) {
  return request({
    url: "/orders/handleInvalid/" + id,
    method: "get"
  });
}

// 审核订单
export function checkOrder(id) {
  return request({
    url: "/orders/handleProcess/" + id,
    method: "get"
  });
}

// 订单明细
export function getDetailList(query) {
  return request({
    url: "/orders/orderItemList",
    method: "get",
    params: query
  });
}

// 订单列表
export function fetchList(query) {
  return request({
    url: "/orders/list",
    method: "get",
    params: query
  });
}

export function queryWarehouseNameALL() {
  return request({
    url: "/orders/queryWarehouseName",
    method: "get"
  });
}
// 订单详情
export function getById(id) {
  return request({
    url: "/orders/info/" + id,
    method: "get"
  });
}
// 全部退款理由查询
export function getAllReason() {
  return request({
    url: "/orders/getAllReason",
    method: "get"
  });
}
//取消发货
export function cancelDelivery(id) {
  return request({
    url: "/orders/cancelDelivery/" + id,
    method: "get"
  });
}
//部分取消发货
export function partlyCancelOrder(data) {
  return request({
    url: "/orders/partlyCancelOrder",
    method: "post",
    data
  });
}
//推送订单到国内OMS 针对已作废和未推送过的单
export function pushOrderToOms(id) {
  return request({
    url: "/orders/pushOrderToOms/" + id,
    method: "get"
  });
}

const orderTypeOptions = [
  { key: "fixed", display_name: "正常订单" },
  { key: "pre", display_name: "预售订单" },
  { key: "manual", display_name: "手工订单" },
  { key: "point", display_name: "积分订单" },
  { key: "exChange", display_name: "换货订单" },
  { key: "conversion", display_name: "兑换订单" },
  { key: "data", display_name: "FBA订单" }
];
export const orderTypeKeyValue = orderTypeOptions.reduce((acc, cur) => {
  acc[cur.key] = cur.key;
  return acc;
}, {});

const statusOptions = [
  { key: "unchecked", display_name: "未审核" },
  { key: "check", display_name: "已审核" },
  { key: "undelivery", display_name: "未发货" },
  { key: "delivery", display_name: "已发货" },
  { key: "off", display_name: "已完成" },
  { key: "cancel", display_name: "已作废" },
  { key: "partdelivery", display_name: "部分发货" }
];
export const statusKeyValue = statusOptions.reduce((acc, cur) => {
  acc[cur.key] = cur.key;
  return acc;
}, {});

function $t(key) {
  return i18n.t(key);
}

const ormstatusOptions = [
  { key: "WAIT_SELLER_SEND_GOODS", display_name: "买家已付款" },
  { key: "WAIT_BUYER_CONFIRM_GOODS", display_name: "卖家已发货" },
  { key: "FINISHED", display_name: "交易成功" },
  { key: "CLOSED", display_name: "交易关闭" },
  { key: "SELLER_CONSIGNED_PART", display_name: "买家已签收" }
];
export const ormstatusKeyValue = ormstatusOptions.reduce((acc, cur) => {
  acc[cur.key] = cur.display_name;
  return acc;
}, {});

const typeSaleOptions = [
  { key: "nosale", display_name: "非预售" },
  { key: "tmsale", display_name: "天猫预售" },
  { key: "waysale", display_name: "在途预售" },
  { key: "zjsale", display_name: "征集预售" },
  { key: "klsale", display_name: "考拉预售" },
  { key: "presale", display_name: "预付款" }
];
export const typeSaleKeyValue = typeSaleOptions.reduce((acc, cur) => {
  acc[cur.key] = cur.display_name;
  return acc;
}, {});

//获取国家信息
export function getReceiverCountryList(query) {
  return request({
    url: "/address/getCountry",
    method: "get",
    params: query
  });
}


//获取可换货的sku
export function getSku(query) {
  return request({
    url: "/orderItems/querySku",
    method: "get",
    params: query
  });
}



export function exchangeGoods(data) {
  return request({
    url: "/orders/exchangeGoods",
    method: "get",
    params: data
  });
}

export function getLogData(id) {
  return request({
    url: "/orders/getLogData/" + id,
    method: "get"
  });
}

//验证导出
export function verifyExport(query){
  return request({
    url: "/orders/verifyExport",
    method: "get",
    params: query
  });
}

//通过网店单号或shopify单号获取所有详情
export function getDetailListForRefund(query) {
  return request({
    url:  '/orders/getDetailListForRefund',
    method: 'get',
    params: query
  })
}

//获取订单详情
export function getDetailListByOrderId(query) {
  return request({
    url:  '/orderItems/list',
    method: 'get',
    params: query
  })
}

//获取订单明细详情
export function getDetailListByOrderInfo(query) {
  return request({
    url:  '/orderItems/orderItemLists',
    method: 'get',
    params: query
  })
}
