import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

import Layout from "@/layout";

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirect in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
 meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
**/
export const constantRoutes = [
  {
    path: "/login",
    component: () => import("@/views/login/index"),
    hidden: true
  },
  {
    path: "/404",
    component: () => import("@/views/404"),
    hidden: true
  },
  {
    path: "/guide",
    component: () => import("@/views/guide"),
    hidden: true
  },
  {
    path: "/",
    component: Layout,
    redirect: "/index",
    name: "index",
    hidden: true,
    meta: {
      title: "dashboard"
    },
    children: [
      {
        path: "index",
        component: () => import("@/views/oms/order/orderList")
      }
    ]
  },
  {
    path: "/HelpCenter",
    component: () => import("@/views/help/HelpCenter"),
    name: "HelpCenter",
    redirect: "/introduction",
    hidden: true,
    children: [
      {
        path: "/introduction",
        component: () => import("@/views/help/views/introduction")
      },
      {
        path: "/product",
        component: () => import("@/views/help/views/product")
      }
    ]
  }
];
import channelRouter from "./modules/channelRouter";
import categoryRouter from "./modules/categoryRouter";
import attributeRouter from "./modules/attribute";
import productRouter from "./modules/product";
import productConfigRouter from "./modules/productConfig";
import sysRouter from "./modules/sys";
import userAuthRouter from "./modules/userAuth";
import logRouter from "./modules/log";
import orderRouter from "./modules/order";
import inventoryRouter from "./modules/inventory";
import refundRouter from "./modules/refund";
import onTrialRouter from "./modules/onTrial";
import basicConfigRouter from "./modules/basicConfig";
import storageChannelRouter from "@/router/modules/storage";
import promotionRouter from "@/router/modules/promotion";

export const asyncRoutes = [
  userAuthRouter,
  sysRouter,
  orderRouter,
  refundRouter,
  inventoryRouter,
  onTrialRouter,
  basicConfigRouter,
  storageChannelRouter,
  promotionRouter
];

/*export default new Router({
	// mode: 'history', //后端支持可开
	scrollBehavior: () => ({
		y: 0
	}),
	routes: constantRoutes
})*/

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({
      y: 0
    }),
    routes: constantRoutes
  });

const router = createRouter();
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
