import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'
import router, {
	resetRouter
} from '@/router'

const state = {
	token: getToken(),
	name: '',
	loginName:'',
	avatar: '',
	introduction: '',
	roles: [],
	// 用户拥有的按钮资源
  btns: [],
  orgGroup:'',
  orgName:'',
};

const mutations = {
	SET_TOKEN: (state, token) => {
		state.token = token;
	},
	SET_INTRODUCTION: (state, introduction) => {
		state.introduction = introduction;
	},
	SET_NAME: (state, name) => {
		state.name = name;
	},
	SET_AVATAR: (state, avatar) => {
		state.avatar = avatar;
	},
	SET_ROLES: (state, roles) => {
		state.roles = roles;
	},
  SET_BTNS: (state, btns) => {// 设置用户资源按钮
    state.btns = btns
  },
  SET_ORG_GROUP: (state, orgGroup) => {
    state.orgGroup = orgGroup
  },
  SET_ORGNAME:(state,orgName)=>{
  	state.orgName = orgName;
  },
  SET_LOGINNAME:(state,loginName)=>{
  	state.loginName = loginName;
  }
};

const actions = {
	// user login
	login({commit}, userInfo) {
		const {username,password} = userInfo ;
		return new Promise((resolve, reject) => {
			login({username: username.trim(),password: password}).then(
				response => {
					const {data} = response;
					commit('SET_TOKEN', data.token);

					setToken(data.token);
					resolve();
				}).catch(error => {
					reject(error);
				});
		})
	},

	// get user info
	getUserInfo({commit,state	}) {
		return new Promise((resolve, reject) => {
			getInfo(state.token).then(response => {
				const orgGroup = response.orgGroup;
        const orgName = response.orgName;
				const data = response.data;

				if(data.roles && data.roles.length > 0) {
          commit('SET_ROLES', data.roles)
        } else {
          reject('getInfo: roles must be a non-null array !')
        }
        //名称
        commit('SET_NAME', data.nickname);
        //按钮权限
        const btns = data.perms;
        sessionStorage.setItem('userBtns', btns);
        //头像
        commit('SET_AVATAR', data.avatar);
        //用户名
        commit('SET_LOGINNAME',response.userName);
        //组织名称
        commit('SET_ORGNAME', orgName);
       	//组织角色
        if (orgGroup !== null && orgGroup !== '') {
          commit('SET_ORG_GROUP', orgGroup.orgGroupCode);
        }
				resolve(response);
			}).catch(error => {
				reject(error);
			})
		})
	},

	// user logout
	logout({commit,state,dispatch}) {
		return new Promise((resolve, reject) => {
			logout(state.token).then(() => {
				commit('SET_TOKEN', '');
				commit('SET_ROLES', []);
				removeToken();
				resetRouter();
				dispatch('tagsView/delAllViews', null, {
					root: true
				});
				resolve();
			}).catch(error => {
				reject(error)
			});
		})
	},

	// remove token
	resetToken({commit}) {
		return new Promise(resolve => {
			commit('SET_TOKEN', '');
			commit('SET_ROLES', []);
			removeToken();
			resolve();
		})
	},

	// dynamically modify permissions
	changeRoles({commit,dispatch}, role) {
		return new Promise(async resolve => {
			const token = role + '-token';

			commit('SET_TOKEN', token);
			setToken(token);
			// by zjj
			const res	= await dispatch('user/getUserInfo');
			let data = res.data.list; // router 连接
			// by zjj

			resetRouter();

			// generate accessible routes map based on roles
			const accessRoutes = await dispatch('permission/generateRoutes', data, {
				root: true
			});

			// dynamically add accessible routes
			router.addRoutes(accessRoutes);

			// reset visited views and cached views
			dispatch('tagsView/delAllViews', null, {
				root: true
			});

			resolve()
		})
	}
};

export default {
	namespaced: true,
	state,
	mutations,
	actions
}
