import axios from 'axios'
import { Message, MessageBox } from 'element-ui'
import store from '../store'
import { getToken } from '@/utils/auth'

// 创建axios实例
const service = axios.create({
  baseURL: process.env.BASE_API, // api 的 base_url
  timeout: 50000 // 请求超时时间
});

// request拦截器
service.interceptors.request.use(
  config => {
    if (store.getters.token) {
      config.headers['X-Token'] = getToken() // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    return config
  },
  error => {
    // Do something with request error
    console.log(error); // for debug
    Promise.reject(error)
  }
);

// response 拦截器
service.interceptors.response.use(
  response => {
    //code为非20000是抛错 可结合自己业务进行修改
    let res = response.data;
    if (res.code !== 200) {
      Message.closeAll();
      Message({
        message: res.msg,
        type: 'error',
        duration: 5 * 1000
      });
      if (typeof(res) == "string"){
        res = JSON.parse(res)
      }
      // 用户模块
      if (res.code === 401){
        Message.closeAll();
        MessageBox.confirm(res.msg, '确定登出', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          store.dispatch('FedLogOut').then(() => {
            location.reload() // 为了重新实例化vue-router对象 避免bug
          })
        })
      } else {
        return Promise.reject('error');
      }
    } else {
      return response.data
    }
  },
  error => {
    console.log('err' + error); // for debug
    Message.closeAll();
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    });
    return Promise.reject(error)
  }
);

export default service
