import axios from 'axios'
import { Message, MessageBox } from 'element-ui'
import store from '../store'
import { getToken } from '@/utils/auth'

//忽略报错的连接
const ignoreMessage = ["/autoparts/pimCatentry/getProductAttr"];

// 创建axios实例
const service = axios.create({
  baseURL: process.env.VUE_APP_OAUTH_API, // api 的 base_url
  timeout: 50000 // 请求超时时间
});

// request拦截器
service.interceptors.request.use(
  config => {
    if(store.getters.token) {
      config.headers['X-Token'] = getToken() // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    return config
  },
  error => {
    // Do something with request error
    Promise.reject(error).then(error=>{
    	console.error(error); // for debug
    })
  }
);

// response 拦截器
service.interceptors.response.use(
  response => {
    /**
     * code为非20000是抛错 可结合自己业务进行修改
     */
    let res = response.data;
    if (res.code && res.code !== 200) {
    	let currUrl = response.config.url;
    	if(ignoreMessage.indexOf(currUrl) < 0){
    		//弹框错误信息
        Message.closeAll();
    		Message({message: res.msg,type: 'error',duration: 3 * 1000})
    	}
      if (typeof(res) == "string"){
        res = JSON.parse(res)
      }
      //console.log(res);
      // 用户模块
      if (res.code === 401){
        Message.closeAll();
        MessageBox.confirm(res.msg, '确定登出', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
        	// 为了重新实例化vue-router对象 避免bug
          store.dispatch('user/logout').then(() => {location.reload()})
        })
      } else {
        return Promise.reject(response.data);
      }
    } else {
      return response.data
    }
  },
  error => {
    console.log('err' + error); // for debug
    if(error.config.url.indexOf('/cms/') > -1){
    	console.error('请求返回异常：' + error)
    }else{
      Message.closeAll();
	    Message({message: error.message,type: 'error',duration: 3 * 1000})
    }
    return Promise.reject(error)

  }
);

export default service
