"use strict";
const path = require("path");
const defaultSettings = require("./src/settings.js");

function resolve(dir) {
  return path.join(__dirname, dir);
}
const name = defaultSettings.title || "歌莉娅海外订单中心（FOMS）"; // 标题
const port = process.env.port || process.env.npm_config_port || 9527; // 开发接口

// 所有配置项描述 查看： https://cli.vuejs.org/config/
module.exports = {
  publicPath: "./", // 基本路径
  outputDir: "dist", // 输出文件目录
  assetsDir: "static", // 放置生成的静态资源 (js、css、img、fonts) 的 (相对于 outputDir 的) 目录。
  // 指定生成的 index.html 的输出路径 (相对于 outputDir)。也可以是一个绝对路径
  // indexPath: './',
  lintOnSave: process.env.NODE_ENV === "production", // lintOnSave: eslint-loader 是否在保存的时候检查
  productionSourceMap: false, // 生产环境是否生成 sourceMap 文件
  devServer: {
    port: port,
    // host: "swings.pim.com",
    // open: true,
    overlay: {
      warnings: false,
      errors: true
    },
    public: "0.0.0.0:9527", //可以实现热部署
    proxy: {
      [process.env.VUE_APP_OAUTH_API]: {
        target: `http://localhost:19090/sso`,
        changeOrigin: true,
        // logLevel: 'debug', //打印日志
        pathRewrite: {
          ['^' + process.env.VUE_APP_OAUTH_API]: ''
        }
      },
      [process.env.VUE_APP_PIM_API]: {
        target: `http://localhost:18080/pim`,
        changeOrigin: true,
        // logLevel: 'debug', //打印日志
        pathRewrite: {
          ['^' + process.env.VUE_APP_PIM_API]: ''
        }
      },
      [process.env.VUE_APP_OMS_API]: {
        target: `http://localhost:18081/oms`,
        changeOrigin: true,
        // logLevel: 'debug', //打印日志
        pathRewrite: {
          ['^' + process.env.VUE_APP_OMS_API]: ''
        }
      }
      // "/": {
      //   target: "https://testfoms.gloria.com.cn",
      //   changeOrigin: true
      // },
      //http://10.41.3.152:18081  http://10.41.3.65:19090
      // [process.env.VUE_APP_OAUTH_API]: {
      //   target: `http://10.41.3.65:19090/sso`,
      //   changeOrigin: true,
      //   // logLevel: 'debug', //打印日志
      //   pathRewrite: {
      //     ['^' + process.env.VUE_APP_OAUTH_API]: ''
      //   }
      // },
      // [process.env.VUE_APP_PIM_API]: {
      //   target: `http://10.41.3.65:18081/pim`,
      //   changeOrigin: true,
      //   // logLevel: 'debug', //打印日志
      //   pathRewrite: {
      //     ['^' + process.env.VUE_APP_PIM_API]: ''
      //   }
      // },
      // [process.env.VUE_APP_OMS_API]: {
      //   target: `http://10.41.3.106:18081/oms`, // 胡超
      //   changeOrigin: true,
      //   // logLevel: 'debug', //打印日志
      //   pathRewrite: {
      //     ['^' + process.env.VUE_APP_OMS_API]: ''
      //   }
      // },
      // [process.env.VUE_APP_OMS_API]: { // 林群
      //   target: `http://10.41.3.65:18081/oms`,
      //   changeOrigin: true,
      //   // logLevel: 'debug', //打印日志
      //   pathRewrite: {
      //     ['^' + process.env.VUE_APP_OMS_API]: ''
      //   }
      // },
      // [process.env.VUE_APP_OMS_API]: {   // 廖望
      //   target: `http://10.41.3.152:18081/oms`,
      //   changeOrigin: true,
      //   // logLevel: 'debug', //打印日志
      //   pathRewrite: {
      //     ['^' + process.env.VUE_APP_OMS_API]: ''
      //   }
      // },

    }
  },
  // webpack配置
  configureWebpack: {
    name: name,
    resolve: {
      alias: {
        "@": resolve("src")
      }
    }
  },
  chainWebpack(config) {
    // 删除预加载
    config.plugins.delete("preload"); // TODO: need test
    config.plugins.delete("prefetch"); // TODO: need test

    // set svg-sprite-loader
    config.module
      .rule("svg")
      .exclude.add(resolve("src/icons"))
      .end();
    config.module
      .rule("icons")
      .test(/\.svg$/)
      .include.add(resolve("src/icons"))
      .end()
      .use("svg-sprite-loader")
      .loader("svg-sprite-loader")
      .options({
        symbolId: "icon-[name]"
      })
      .end();

    // set preserveWhitespace
    config.module
      .rule("vue")
      .use("vue-loader")
      .loader("vue-loader")
      .tap(options => {
        options.compilerOptions.preserveWhitespace = true;
        return options;
      })
      .end();

    config
      // https://webpack.js.org/configuration/devtool/#development
      .when(process.env.NODE_ENV === "development", config =>
        config.devtool("cheap-source-map")
      );

    config.when(process.env.NODE_ENV !== "development", config => {
      //非开发环境
      config
        .plugin("ScriptExtHtmlWebpackPlugin")
        .after("html")
        .use("script-ext-html-webpack-plugin", [
          {
            // `runtime` must same as runtimeChunk name. default is `runtime`
            inline: /runtime\..*\.js$/
          }
        ])
        .end();

      // 分割代码
      config.optimization.splitChunks({
        chunks: "all",
        cacheGroups: {
          libs: {
            name: "chunk-libs",
            test: /[\\/]node_modules[\\/]/,
            priority: 10,
            chunks: "initial" // only package third parties that are initially dependent
          },
          elementUI: {
            name: "chunk-elementUI", // split elementUI into a single package
            priority: 20, // the weight needs to be larger than libs and app or it will be packaged into libs or app
            test: /[\\/]node_modules[\\/]_?element-ui(.*)/ // in order to adapt to cnpm
          },
          commons: {
            name: "chunk-commons",
            test: resolve("src/components"), // can customize your rules
            minChunks: 3, //  minimum common number
            priority: 5,
            reuseExistingChunk: false
          }
        }
      });
      config.optimization.runtimeChunk("single");
    });
  }
};
